@@ -4,18 +4,18 @@
 #'
 #' @author Greg Pilgrim \email{gpilgrim2670@@gmail.com}
 #'
-#' @importFrom  stringr str_detect
+#' @importFrom stringr str_detect
 #' @importFrom rvest html_nodes
 #' @importFrom rvest html_text
 #' @importFrom pdftools pdf_text
 #'
 #' @param file a .pdf or .html file (could be a url) where containing swimming results.  Must be formatted in a "normal" fashion - see vignette
 #' @param node a CSS node where html results are stored.  Required for html results.
-#' @return returns a list of strings containing the information from \code{x}.  Should then be parsed with \code{Swim_Parse}
+#' @return returns a list of strings containing the information from \code{x}.  Should then be parsed with \code{swim_parse}
 #'
-#' @examples \dontrun{Read_Results("http://www.nyhsswim.com/Results/Boys/2008/NYS/Single.htm", node = "pre")}
+#' @examples \dontrun{read_results("http://www.nyhsswim.com/Results/Boys/2008/NYS/Single.htm", node = "pre")}
 #'
-#' @seealso \code{Read_Results} is meant to be followed by \code{\link{Swim_Parse}}
+#' @seealso \code{read_results} is meant to be followed by \code{\link{swim_parse}}
 #'
 #' @export
 
@@ -30,7 +30,7 @@ Read_Results <- function(file, node = NULL) {
     if(is.character(node) == FALSE) {
   stop(" Please supply a value for node")
     } else {
-  webpage <- read_html(file)
+  webpage <- xml2::read_html(file)
   html <- rvest::html_nodes(webpage, node)
   results <- rvest::html_text(html)
 
